#
# spec file for package python-Mathics-Scanner
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-Mathics-Scanner
Version:        1.3.0
Release:        1.3
Summary:        Character Tables and Tokenizer for Mathics and the Wolfram Language
License:        GPL-3.0-only
URL:            https://mathics.org/
Source:         https://files.pythonhosted.org/packages/source/M/Mathics-Scanner/Mathics_Scanner-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module chardet}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module pytest}
# /SECTION
BuildRequires:  fdupes
Requires:       python-PyYAML
Requires:       python-chardet
Requires:       python-click
Requires(post): update-alternatives
Requires(postun):update-alternatives
Recommends:     python-ujson
BuildArch:      noarch
%python_subpackages

%description
Character Tables and Tokenizer for Mathics and the Wolfram Language.

%prep
%setup -q -n Mathics_Scanner-%{version}
# Fix shbang
sed -i "s|/usr/bin/env python|/usr/bin/python3|" mathics_scanner/generate/build_tables.py
sed -i "s|/usr/bin/env python3|/usr/bin/python3|" mathics_scanner/generate/rl_inputrc.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/mathics-generate-json-table
%python_expand %fdupes %{buildroot}%{$python_sitelib}
# Should be executable
%python_expand chmod 0755 %{buildroot}%{$python_sitelib}/mathics_scanner/generate/{build_tables,rl_inputrc}.py

%check
%pytest

%post
%python_install_alternative mathics-generate-json-table

%postun
%python_uninstall_alternative mathics-generate-json-table

%files %{python_files}
%python_alternative %{_bindir}/mathics-generate-json-table
%{python_sitelib}/mathics_scanner/
%{python_sitelib}/Mathics_Scanner-%{version}-py%{python_version}.egg-info/

%changelog
* Mon Apr 10 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.3.0:
  * Add escape-code sequence for 32-bit Unicode
    (gh#Mathics3/mathics-scanner#48).
  * Correct Infix and Tilde character symbols
  * Support double backslash (\\) as a single backslash character
    (\).
  * Correct Unicode for ScriptN and ScriptCaptialN
  * Correct a number of is-letter-like entries.
  * Accept \u21A6 as symbol for Function.
  * Change the precedence of |->(Function symbol) to 800 so it
    isn't interpreted as a | followed by ->
  * ASCII operator tables can now be generated
  * Add DifferentialD and Integrate even though we don't have a
    full set of prefix operators.
  * More precedence values added to operators
  * Python 3.11 operation verified
- Drop 9346764dfd22f011ec7bba9248497383f4b98a3a.patch:
  incorporated upstream.
- Requires(post): update-alternatives for correct post scriptlet
  runs.
* Sun Jul 11 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.2.4
  * Start adding AMSLateX names.
  * Add ``ApplyTo``, and ``Factorial2``.
  * Adjust ``Tilde``, and ``Factorial``.
  * Regularize unicode equivalents.
- Add 9346764dfd22f011ec7bba9248497383f4b98a3a.patch
* Sat Jul 10 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Initial package at version 1.2.3 for Mathics3
